# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.api.combatlog_api import CombatlogApi


class TestCombatlogApi(unittest.TestCase):
    """CombatlogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CombatlogApi()

    def tearDown(self) -> None:
        pass

    def test_combatlog_download(self) -> None:
        """Test case for combatlog_download

        Combat Log Download
        """
        pass

    def test_combatlog_list(self) -> None:
        """Test case for combatlog_list

        """
        pass

    def test_combatlog_read(self) -> None:
        """Test case for combatlog_read

        """
        pass

    def test_combatlog_upload(self) -> None:
        """Test case for combatlog_upload

        Combat Log Upload
        """
        pass


if __name__ == '__main__':
    unittest.main()
