# coding: utf-8

# flake8: noqa

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.3"

# import apis into sdk package
from OSCR_django_client.api.combatlog_api import CombatlogApi
from OSCR_django_client.api.ladder_api import LadderApi
from OSCR_django_client.api.ladder_entries_api import LadderEntriesApi
from OSCR_django_client.api.variant_api import VariantApi

# import ApiClient
from OSCR_django_client.api_response import ApiResponse
from OSCR_django_client.api_client import ApiClient
from OSCR_django_client.configuration import Configuration
from OSCR_django_client.exceptions import OpenApiException
from OSCR_django_client.exceptions import ApiTypeError
from OSCR_django_client.exceptions import ApiValueError
from OSCR_django_client.exceptions import ApiKeyError
from OSCR_django_client.exceptions import ApiAttributeError
from OSCR_django_client.exceptions import ApiException

# import models into sdk package
from OSCR_django_client.models.combat_log import CombatLog
from OSCR_django_client.models.combat_log_upload_response import CombatLogUploadResponse
from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response
from OSCR_django_client.models.ladder import Ladder
from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry
from OSCR_django_client.models.ladder_list200_response import LadderList200Response
from OSCR_django_client.models.metadata import Metadata
from OSCR_django_client.models.variant import Variant
from OSCR_django_client.models.variant_list200_response import VariantList200Response
