# coding: utf-8

# flake8: noqa
"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from OSCR_django_client.models.combat_log import CombatLog
from OSCR_django_client.models.combat_log_upload_response import CombatLogUploadResponse
from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response
from OSCR_django_client.models.ladder import Ladder
from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry
from OSCR_django_client.models.ladder_list200_response import LadderList200Response
from OSCR_django_client.models.metadata import Metadata
from OSCR_django_client.models.variant import Variant
from OSCR_django_client.models.variant_list200_response import VariantList200Response
