# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.api.variant_api import VariantApi


class TestVariantApi(unittest.TestCase):
    """VariantApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VariantApi()

    def tearDown(self) -> None:
        pass

    def test_variant_list(self) -> None:
        """Test case for variant_list

        """
        pass

    def test_variant_read(self) -> None:
        """Test case for variant_read

        """
        pass


if __name__ == '__main__':
    unittest.main()
