# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder import Ladder

class TestLadder(unittest.TestCase):
    """Ladder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Ladder:
        """Test Ladder
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Ladder`
        """
        model = Ladder()
        if include_optional:
            return Ladder(
                id = 56,
                variant_name = '',
                name = '0',
                difficulty = '0',
                is_solo = True,
                is_space = True,
                metric = '0',
                variant = ''
            )
        else:
            return Ladder(
                name = '0',
                metric = '0',
                variant = '',
        )
        """

    def testLadder(self):
        """Test Ladder"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
