# flake8: noqa

# import apis into api package
from OSCR_django_client.api.combatlog_api import CombatlogApi
from OSCR_django_client.api.ladder_api import LadderApi
from OSCR_django_client.api.ladder_entries_api import LadderEntriesApi
from OSCR_django_client.api.variant_api import VariantApi

