# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.variant_list200_response import VariantList200Response

class TestVariantList200Response(unittest.TestCase):
    """VariantList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VariantList200Response:
        """Test VariantList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VariantList200Response`
        """
        model = VariantList200Response()
        if include_optional:
            return VariantList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.variant.Variant(
                        name = '0', 
                        start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_ground_variant = True, 
                        is_space_variant = True, 
                        exclude_space = [
                            ''
                            ], 
                        exclude_ground = [
                            ''
                            ], )
                    ]
            )
        else:
            return VariantList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.variant.Variant(
                        name = '0', 
                        start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_ground_variant = True, 
                        is_space_variant = True, 
                        exclude_space = [
                            ''
                            ], 
                        exclude_ground = [
                            ''
                            ], )
                    ],
        )
        """

    def testVariantList200Response(self):
        """Test VariantList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
