# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response

class TestCombatlogList200Response(unittest.TestCase):
    """CombatlogList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombatlogList200Response:
        """Test CombatlogList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombatlogList200Response`
        """
        model = CombatlogList200Response()
        if include_optional:
            return CombatlogList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.combat_log.CombatLog(
                        id = 56, 
                        metadata = OSCR_django_client.models.metadata.Metadata(
                            id = 56, 
                            map = '0', 
                            difficulty = '0', 
                            summary = OSCR_django_client.models.summary.Summary(), 
                            date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        youtube = '0', )
                    ]
            )
        else:
            return CombatlogList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.combat_log.CombatLog(
                        id = 56, 
                        metadata = OSCR_django_client.models.metadata.Metadata(
                            id = 56, 
                            map = '0', 
                            difficulty = '0', 
                            summary = OSCR_django_client.models.summary.Summary(), 
                            date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        youtube = '0', )
                    ],
        )
        """

    def testCombatlogList200Response(self):
        """Test CombatlogList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
