# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder_entry import LadderEntry

class TestLadderEntry(unittest.TestCase):
    """LadderEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LadderEntry:
        """Test LadderEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LadderEntry`
        """
        model = LadderEntry()
        if include_optional:
            return LadderEntry(
                id = 56,
                var_date = '',
                rank = 56,
                player = '0',
                data = OSCR_django_client.models.data.Data(),
                combatlog = 56,
                ladder = 56
            )
        else:
            return LadderEntry(
                player = '0',
                data = OSCR_django_client.models.data.Data(),
                combatlog = 56,
                ladder = 56,
        )
        """

    def testLadderEntry(self):
        """Test LadderEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
