# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder_list200_response import LadderList200Response

class TestLadderList200Response(unittest.TestCase):
    """LadderList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LadderList200Response:
        """Test LadderList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LadderList200Response`
        """
        model = LadderList200Response()
        if include_optional:
            return LadderList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.ladder.Ladder(
                        id = 56, 
                        variant_name = '', 
                        name = '0', 
                        difficulty = '0', 
                        is_solo = True, 
                        is_space = True, 
                        metric = '0', 
                        variant = '', )
                    ]
            )
        else:
            return LadderList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.ladder.Ladder(
                        id = 56, 
                        variant_name = '', 
                        name = '0', 
                        difficulty = '0', 
                        is_solo = True, 
                        is_space = True, 
                        metric = '0', 
                        variant = '', )
                    ],
        )
        """

    def testLadderList200Response(self):
        """Test LadderList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
